@@ -15,13 +15,6 @@ module Debian.Relation.ByteString
     , ParseRelations(..)
     ) where 
 
--- Standard GHC Modules
-
-import Data.List
-import Text.ParserCombinators.Parsec
-
--- 3rd Party Modules
-
 import qualified Data.ByteString.Char8 as C
 
 -- Local Modules
@@ -34,8 +27,4 @@ import Debian.Relation.String
 
 -- For now we just wrap the string version
 instance ParseRelations C.ByteString where
-    parseRelations byteStr = 
-        let str = C.unpack byteStr in
-        case parse pRelations str str of
-          Right relations -> Right (filter (/= []) relations)
-          x -> x
+    parseRelations byteStr = parseRelations (C.unpack byteStr)
