@@ -19,7 +19,6 @@ module Debian.Relation.String
 
 -- Standard GHC Modules
 
-import Data.List
 import Text.ParserCombinators.Parsec
 
 -- Local Modules
@@ -30,10 +29,16 @@ import Debian.Version
 -- * ParseRelations
 
 instance ParseRelations String where
-    parseRelations str = 
-        case parse pRelations str str of
+    parseRelations str =
+        let str' = scrub str in
+        case parse pRelations str' str' of
           Right relations -> Right (filter (/= []) relations)
           x -> x
+        where
+          scrub = unlines . filter (not . comment) . lines
+          comment s = case dropWhile (`elem` " \t") s of
+                           ('#' : _) -> True
+                           _ -> False
 
 -- * Relation Parser
 
@@ -63,7 +68,7 @@ pRelation =
        mVerReq <- pMaybeVerReq
        skipMany whiteChar
        mArch <- pMaybeArch
-       return $ Rel pkgName mVerReq mArch
+       return $ Rel (BinPkgName (PkgName pkgName)) mVerReq mArch
 
 pMaybeVerReq :: RelParser (Maybe VersionReq)
 pMaybeVerReq =
