@@ -1,42 +1,41 @@
 module Main where
 
-import Control.Monad
-import Data.ByteString.Char8 (ByteString)
 import Debian.Control  -- (Control(..),lookupP,parseControlFromFile)
 import Debian.Relation
 import System.Process
 import System.Exit
 import System.Environment
 
-lookupBuildDeps :: FilePath -> IO [PkgName]
+lookupBuildDeps :: FilePath -> IO [BinPkgName]
 lookupBuildDeps fp =
     do control <- parseControlFromFile fp
-       case control of 
+       case control of
          (Left e) -> error (show e)
+         (Right (Control [])) -> error "Empty control file"
          (Right (Control (p:_))) ->
              return $ ((lookupDepends "Build-Depends" p) ++
                        (lookupDepends "Build-Depends-Indep" p))
 
-lookupDepends :: String -> Paragraph' String -> [PkgName]
-lookupDepends key paragraph = 
+lookupDepends :: String -> Paragraph' String -> [BinPkgName]
+lookupDepends key paragraph =
     case fieldValue key paragraph of
                 Nothing -> [] -- (Left $ "could not find key " ++ key)
-                (Just relationString) -> 
+                (Just relationString) ->
                     case parseRelations relationString of
                       (Left e) -> error (show e)
                       (Right andRelations) ->
                           map pkgName (concatMap (take 1) andRelations)
     where
-      pkgName :: Relation -> PkgName
+      pkgName :: Relation -> BinPkgName
       pkgName (Rel name _ _) = name
 
 
-aptGetInstall :: [String] -> [PkgName] -> IO ExitCode
+aptGetInstall :: [String] -> [BinPkgName] -> IO ExitCode
 aptGetInstall options pkgnames =
     do (_,_,_,ph)
-         <- createProcess $ proc "apt-get" $ ["install"] ++ options ++ pkgnames
+         <- createProcess $ proc "apt-get" $ ["install"] ++ options ++ map (unPkgName . unBinPkgName) pkgnames
        waitForProcess ph
-       
+
 main :: IO ()
 main
   = do
